"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseCoverageData = void 0;
const path = require("path");
const fs = require("fs");
const readline = require("readline");
const sourceMap = require("source-map");
const generateReportForHvigorw_1 = require("../generateReportForHvigorw");
const previewLogPath = '.test/default/intermediates/test/coverage_data/previewer.log';
const coveragePath = '.test/default/intermediates/test/coverage_data/js_coverage.json';
const testResultPath = '.test/default/intermediates/test/coverage_data/test_result.txt';
const dataTag = 'OHOS_REPORT_COVERAGE_DATA: ';
const classTag = 'OHOS_REPORT_STATUS: class=';
const statusBaseTag = 'OHOS_REPORT_STATUS: ';
const stackTag = 'OHOS_REPORT_STATUS: stack=';
const testCaseTag = 'OHOS_REPORT_STATUS: test=';
const statusCodeTag = 'OHOS_REPORT_STATUS_CODE: ';
const resultTag = 'OHOS_REPORT_RESULT: stream=';
const sourceMapPathStr = '.test/default/intermediates/test/coverage_sourcemap/unitTestSourceMap.map';
const OHOS_REPORT_COVERAGE_PATH = 'OHOS_REPORT_COVERAGE_PATH: ';
let className = '';
let testCaseName = '';
let isStackStatus = false;
let statusBaseIndex = -1;
const parseCoverageData = async (testPreviewerParam) => {
    const Logger = testPreviewerParam.logger;
    const modulePath = testPreviewerParam.modulePath;
    const projectPath = testPreviewerParam.projectPath;
    const previewDirectory = path.join(modulePath, previewLogPath);
    const coverageDirectory = path.join(modulePath, coveragePath);
    const testResultDirectory = path.join(modulePath, testResultPath);
    const isCoverage = testPreviewerParam.coverage === false ? false : true;
    resetStatus();
    const rl = readline.createInterface({
        input: fs.createReadStream(previewDirectory),
        output: process.stdout,
        terminal: false,
    });
    if (fs.existsSync(testResultDirectory)) {
        fs.unlinkSync(testResultDirectory);
    }
    let coverageData = '';
    for await (const line of rl) {
        if (await logStack(line, Logger, testResultDirectory, modulePath)
            || logClassAndTestSuite(line, testResultDirectory)
            || logTestResult(line, testResultDirectory)) {
            continue;
        }
        let dataIndex = line.indexOf(dataTag);
        if (dataIndex != -1) {
            let data = line.substring(dataIndex + dataTag.length);
            coverageData = coverageData + data;
            continue;
        }
        if (line.indexOf(OHOS_REPORT_COVERAGE_PATH) != -1) {
            coverageData = '';
            continue;
        }
    }
    if (coverageData) {
        if (fs.existsSync(coverageDirectory)) {
            fs.unlinkSync(coverageDirectory);
        }
        fs.writeFileSync(coverageDirectory, coverageData, 'utf8');
        Logger.info('coverage data from call back');
    }
    else {
        Logger.info('coverage data from file');
    }
    await generateReport(isCoverage, modulePath, coverageDirectory, projectPath);
};
exports.parseCoverageData = parseCoverageData;
async function logStack(line, logger, filePath, modulePath) {
    let tempStatusBaseIndex = line.indexOf(statusBaseTag);
    if (tempStatusBaseIndex != -1) {
        isStackStatus = line.substring(tempStatusBaseIndex + statusBaseTag.length).startsWith('stack=');
        statusBaseIndex = tempStatusBaseIndex;
    }
    let stackIndex = line.indexOf(stackTag);
    if (stackIndex != -1) {
        let stackContent = line.substring(stackIndex + stackTag.length);
        let errInfo1 = await identifyError(modulePath, stackContent);
        logger.error(errInfo1);
        isStackStatus = true;
        fs.appendFileSync(filePath, errInfo1 + '\n', 'utf8');
        return true;
    }
    if (isStackStatus) {
        let errInfo2 = await identifyError(modulePath, line.substring(statusBaseIndex));
        logger.error(errInfo2);
        fs.appendFileSync(filePath, errInfo2 + '\n', 'utf8');
        return true;
    }
    return false;
}
function logClassAndTestSuite(line, filePath) {
    let classIndex = line.indexOf(classTag);
    if (classIndex != -1) {
        let tempTlassName = line.substring(classIndex + classTag.length);
        if (tempTlassName != className) {
            className = tempTlassName;
            fs.appendFileSync(filePath, `clase=${className}\n`, 'utf8');
        }
        return true;
    }
    let testCaseIndex = line.indexOf(testCaseTag);
    if (testCaseIndex != -1) {
        let tempTestCaseName = line.substring(testCaseIndex + testCaseTag.length);
        if (tempTestCaseName != testCaseName) {
            testCaseName = tempTestCaseName;
            fs.appendFileSync(filePath, `test=${testCaseName}\n`, 'utf8');
        }
        return true;
    }
    return false;
}
function logTestResult(line, filePath) {
    let resultIndex = line.indexOf(resultTag);
    if (resultIndex != -1) {
        let resultContent = line.substring(resultIndex + resultTag.length);
        fs.appendFileSync(filePath, resultContent + '\n', 'utf8');
        return true;
    }
    let statusCodeIndex = line.indexOf(statusCodeTag);
    if (statusCodeIndex != -1) {
        let statusCode = Number.parseInt(line.substring(statusCodeIndex + statusCodeTag.length));
        switch (statusCode) {
            case 0:
                fs.appendFileSync(filePath, 'result=Success\n', 'utf8');
                break;
            case -1:
                fs.appendFileSync(filePath, 'result=Error\n', 'utf8');
                break;
            case -2:
                fs.appendFileSync(filePath, 'result=Failure\n', 'utf8');
                break;
            case -3:
                fs.appendFileSync(filePath, 'result=Ignore\n', 'utf8');
                break;
        }
        return true;
    }
    return false;
}
function resetStatus() {
    className = '';
    testCaseName = '';
    isStackStatus = false;
    statusBaseIndex = -1;
}
async function generateReport(isCoverage, modulePath, coverageDirectory, projectPath) {
    if (!isCoverage) {
        return;
    }
    const initCoveragePath = `${modulePath}/.test/default/intermediates/test/init_coverage.json`;
    if (!fs.existsSync(initCoveragePath)) {
        return;
    }
    const reportPath = `${modulePath}/.test/default/outputs/test/reports`;
    let coverPath = fs.existsSync(coverageDirectory) ? `${coverageDirectory}#${initCoveragePath}` : initCoveragePath;
    await (0, generateReportForHvigorw_1.generateReportForHvigorw)(projectPath, reportPath, coverPath);
}
const identifyError = async (modulePath, stackContent) => {
    const reg = / {4}at \w+? \(.+?:\d+?:\d+?\)/;
    if (!reg.test(stackContent)) {
        return stackContent;
    }
    const stackArr = stackContent.split(':');
    const line = Number(stackArr[1]);
    const column = Number(stackArr[2].substring(0, stackArr[2].length - 1));
    const stackPath = stackArr[0].split('(')[1];
    const sourceMapPath = path.join(modulePath, sourceMapPathStr);
    let sourceMapFile = fs.readFileSync(sourceMapPath, 'utf-8');
    sourceMapFile = sourceMapFile.substring(0, sourceMapFile.length - 1);
    const sourceMapJson = JSON.parse(`{${sourceMapFile}}`);
    let targetKey = '';
    for (let sourcemapKey of Object.keys(sourceMapJson)) {
        if (sourcemapKey.replace(/\\/g, '/').includes(stackPath.replace(/\.ets/g, ''))) {
            targetKey = sourcemapKey;
            break;
        }
    }
    if (!targetKey) {
        return stackContent;
    }
    const consumer = await new sourceMap.SourceMapConsumer(sourceMapJson[targetKey]);
    const originalPosition = consumer.originalPositionFor({
        line: line,
        column: column,
    });
    let newLine = originalPosition.line;
    let newColumn = originalPosition.column;
    return `${stackArr[0]}:${newLine}:${newColumn})`;
};
