/**
 * 用来屏蔽不需要处理的文件
 * 目前rollup编译前端对 .d.ts 和 .d.ets 声明文件的处理逻辑是忽略掉所有的声明文件。因为 rollup 处理不了声明文件，只有tsc能处理声明文件。
 * 最简单的忽略方法是在 transform中把内容置为空，但目前ets-loader默认不搜集声明文件，简单置为空仍然会被ets-loader搜集到。
 * ets-loader不搜集转换(abc)声明文件导致了一个问题，如果我们在声明文件中导出一个 class 等 value 目前是不支持的, 要直接报错。
 * 我们和ets-loader约定 ets-loader 默认不搜集转换虚拟文件（rollup中虚拟文件以\0开头），所以我们可以把声明文件转换成虚拟文件。
 * 之前的实现逻辑是把所有的声明文件统一转成一个虚拟文件 rollup_plugin_ignore_empty_module_placeholder， 这样丢失了源文件信息导致
 * 声明文件报错时区分不出来是哪个声明文件报的错。所以目前的修改方案是把每一个声明文件都转成一个虚拟文件，用声明文件的路径信息拼接出一个虚拟文件。
 *
 * @param ignoreFilter 正则表达式
 */
export declare function ignorePlugin(ignoreFilter: RegExp): {
    name: string;
    resolveId(importee: string): string | null;
    load(id: string): "" | null;
};
