/**
 * 模块配置
 * 来源: 模块级build-profile.json5、module.json5
 */
export interface ModuleConfigTrace {
    MODULE_NAME: string;
    API_TYPE?: string;
    TARGETS?: Record<string, any>[];
    OBFUSCATION?: Record<string, any>;
    WORKERS?: string[];
    BUILD_PROFILE_FIELDS?: Record<string, any>;
    DEVICE_TYPES: string[];
    METADATA?: {
        NAME?: string;
        RESOURCE?: string;
    }[];
}
/**
 * 工程级配置
 */
export interface ProjectConfigTrace {
    PRODUCTS?: Record<string, any>[];
    MODULES?: Record<string, any>[];
    BUILD_MODE_SET?: Record<string, any>[];
    BUILD_MODE?: string;
    aotCompileMode?: string;
}
/**
 * hvigor-ohos-plugin的所有打点数据
 */
interface OhosTraceMessage {
    PROJECT_CONFIG?: ProjectConfigTrace;
    MODULE_CONFIG: ModuleConfigTrace[];
    ERROR_MESSAGE?: {
        TASK_TYPE: string;
        ERROR_CODE: string;
    };
}
declare class OhosTrace {
    private pluginName;
    private taskName;
    private readonly _data;
    constructor();
    getData(): OhosTraceMessage;
    setTaskName(name: string): void;
    setProjectConfig(projectConfig: ProjectConfigTrace): void;
    setAotCompilerMode(aotCompileMode: string): void;
    /**
     * 替换模块数据，防止daemon模式出现数据重复
     * @param {ModuleConfigTrace} config
     */
    replaceModuleConfig(config: ModuleConfigTrace): void;
    /**
     * 将打点数据传给hvigor
     * @param {boolean} isFailed true:构建失败; false:构建成功;
     */
    traceToHvigor(isFailed?: boolean): void;
}
export declare const ohosTrace: OhosTrace;
export {};
